@@ -3,6 +3,7 @@
 
 # imports.
 from fir3base.v1.classes.config import *
+from fir3base.v1.classes import utils
 
 # the firebase class.
 class Firebase(object):
@@ -210,9 +211,11 @@ class Users(object):
 		# the mode id.
 		mode="verification",
 		# the mode title.
-		html="Account Activation",
-		# the path to the html file.
-		html=None,
+		title="Account Activation",
+		# the html (str).
+		html="",
+		# optionally specify the code (leave None to generate).
+		code=None,
 	):
 
 		# check email.
@@ -223,7 +226,8 @@ class Users(object):
 			if response["error"] != None: return response
 				
 		# save code.
-		code = Formats.Integer(0).generate(length=6)
+		if code == None:
+			code = Formats.Integer(0).generate(length=6)
 		response = self.get(uid=uid, email=email)
 		if response["error"] != None: return response
 		user = response["user"]
@@ -234,19 +238,6 @@ class Users(object):
 			"stamp":Formats.Date().timestamp,
 			"attempts":3,
 		}
-
-		# send email.
-		html = utils.__load_file__(html).format(
-			code=code,
-			client=user.display_name,
-			ip=ip,
-			timestamp=Formats.Date().timestamp,
-			white=TEMPLATE_DATA["colors"]["white"],
-			dark_grey=TEMPLATE_DATA["colors"]["dark_grey"],
-			purple=TEMPLATE_DATA["colors"]["purple"],
-			grey=TEMPLATE_DATA["colors"]["grey"],
-			black=TEMPLATE_DATA["colors"]["black"],
-			tint=TEMPLATE_DATA["colors"]["backgrounds"]["top_bar"],)
 		
 		# send email.
 		response = self.email.send(
